@@ -1,8 +1,8 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 8 -*-
+// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
 //
 // Evaluator.h: Rcpp R/C++ interface class library -- protected evaluation
 //
-// Copyright (C) 2009 - 2011	Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2009 - 2012    Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -22,17 +22,17 @@
 #ifndef Rcpp_Evaluator_h
 #define Rcpp_Evaluator_h
 
-#include <RcppCommon.h>
-#include <Rcpp/Environment.h>
+#define R_NO_REMAP
+#include <Rinternals.h>
 
 namespace Rcpp{ 
 
-class Evaluator{
-public:
-		
-	static SEXP run(SEXP expr) throw(eval_error) ; 
-	static SEXP run(SEXP expr, SEXP env) throw(eval_error) ;
-};
+    class Evaluator{
+    public:
+                
+        static SEXP run(SEXP expr); 
+        static SEXP run(SEXP expr, SEXP env);
+    };
 
 } // namespace Rcpp
 
