@@ -2,7 +2,7 @@
 //
 // exceptions.h: Rcpp R/C++ interface class library -- exceptions
 //
-// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2012 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -22,6 +22,13 @@
 #ifndef Rcpp__exceptions__h
 #define Rcpp__exceptions__h
 
+#define R_NO_REMAP
+#include <Rinternals.h>
+#include <sstream>
+
+SEXP stack_trace( const char *file, int line) ;
+#define GET_STACKTRACE() stack_trace( __FILE__, __LINE__ )
+
 namespace Rcpp{
 
 class exception : public std::exception {
@@ -119,4 +126,26 @@ RCPP_EXCEPTION_CLASS(eval_error, message )
 
 } // namesapce Rcpp
 
+void forward_exception_to_r( const std::exception& ) ;
+SEXP exception_to_try_error( const std::exception& ) ;
+SEXP exception_to_r_condition( const std::exception& ) ;
+SEXP string_to_try_error( const std::string& ) ;
+
+std::string demangle( const std::string& name) ;
+#define DEMANGLE(__TYPE__) demangle( typeid(__TYPE__).name() ).c_str() 
+
+namespace Rcpp{
+    /* internal namespace for things not intended to be used by the user */
+    namespace internal{     
+        
+        SEXP try_catch( SEXP expr, SEXP env );
+        SEXP try_catch( SEXP expr );
+        
+    } // namespace internal 
+} // namespace Rcpp
+
+namespace Rcpp {
+	  inline void stop(const std::string& message) { throw Rcpp::exception(message.c_str()); }
+} // namespace Rcpp
+
 #endif
